//
//  IDDeviceConnectionManager.h
//  iDeviceInterface
//
//  Created by Chris Devor on 7/14/11.
//  Copyright 2011 Macroplant. All rights reserved.
//

#import <Foundation/Foundation.h>



typedef enum _IDIDeviceErrorCode {
   IDIDeviceErrorCode_Unknown,
   
   IDIDeviceErrorCode_AFCRead,   // Error reading file from device
   IDIDeviceErrorCode_AFCWrite,  // Error writing to device file
   IDIDeviceErrorCode_FSRead,    // Error reading from local file system
   IDIDeviceErrorCode_FSWrite    // Error writing to local file system
} IDIDeviceErrorCode;

@class IDIDevice;

@protocol IDDeviceConnectionManagerDelegate

- (void) handleDeviceConnected:(IDIDevice *) iDevice;
- (void) handleDeviceDisconnected:(IDIDevice *) iDevice;

- (void) addBusyStatus:(NSString*) busyStatus;
- (void) removeBusyStatus:(NSString*) busyStatus;

- (void) updateProgressToValue:(float)precentComplete forStatus:(NSString*) busyStatus;

@optional

// domain will be "com.macroplant.iDevice"
// localizedDescription will be filled in, if you wish to display it.
// code values are listed in the enum above
- (void) handleError:(NSError*)error;

@end


@interface IDDeviceConnectionManager : NSObject {

    bool allowAFC2Connections;
    NSMutableArray* ma_connectedDevices;
    NSObject <IDDeviceConnectionManagerDelegate> *delegate;
   
   // Whether or not to double-check that a transfer from the device actually transferred correctly.
   // Note that this value will be copied before an actual file transfer, so you can safely change it in the middle
   // of a transfer, and it simply will not take effect until the next tranfer.
   BOOL validateTransfersFromDevice;
    
}

// NOTE: this is left in for now for compatability, however please change to use the setup* class method instead
- (id)initWithDelegate:(NSObject <IDDeviceConnectionManagerDelegate>*)del AllowAFC2Connections:(BOOL) allowAFC2;

+ (IDDeviceConnectionManager*) setupWithDelegate:(NSObject <IDDeviceConnectionManagerDelegate>*)del AllowAFC2Connections:(BOOL) allowAFC2;

+ (IDDeviceConnectionManager *) sharedInstance;


// Atomic and read-write
@property BOOL validateTransfersFromDevice;

@end
